# CHANGES

## 0.6.1

 - BREAKING: Use check_config.toml (in stead of checkers.toml) as default style file
 - Add pre-commit hook

## 0.6.0

- Add optional placeholder when creating a file with file_present
- Add optional placeholder when creating a file with file_regex

## 0.5.1

- Update documentation

## 0.5.0

- Support http(s) location for checkers.

## 0.4.1

- Update dependencies

## 0.4.0

- Refactor checkers
- Add file regex

## 0.3.3

- Add documentation

## 0.3.2

- Fix: improve error handling

## 0.3.1

- Fix: empty json and yaml files where not processed correctly

## 0.3.0

- Support files from Python packages.

## 0.2.0

- Add entry_absent and entry_present

## 0.1.1

- Fix stable classifier

## 0.1.0

- initial release
